
% COST259 Channel Models:

% Note: all these taps (in all the 3 models) have 
%                       Rayleigh Fading Statistics (Ricean Factor K=0) and
%                       A classical (Jake's) Doppler Spectrum

% Model A, corresponding to typical office environment for NLOS conditions 
% and 50ns average rms delay spread
delayA = [0 10 20 30 40 50 60 70 80 90 110 140 170 200 240 290 340 390].*1e-9;
avg_relative_power_dbA = [0.0 -0.9 -1.7 -2.6 -3.5 -4.3 -5.2 -6.1 -6.9 -7.8 -4.7 -7.3 -9.9 -12.5 -13.7 -18.0 -22.4 -26.7];
variancesA = (10.^(avg_relative_power_dbA/10));
[rms_delay_spread_modelA, mean_excess_delay_modelA] = delay_spread(delayA, variancesA)

figure(1)
stem(delayA./1e-9, variancesA)
grid on;
xlabel('Time delay [ns]')
ylabel('Average relative power (dB)')
title('COST259-Model A Power-Delay-Profile')

% Model B, corresponding to typical large open space and office environment
% for NLOS conditions and 100ns average rms delay spread
delayB = [0 10 20 30 50 80 110 140 180 230 280 330 380  430 490 560 640 730].*1e-9;
avg_relative_power_dbB = [-2.6 -3.0 -3.5 -3.9 0.0 -1.3 -2.6 -3.9 -3.4 -5.6 -7.7 -9.9 -12.1 -14.3 -15.4 -18.4 -20.7 -24.6];
variancesB = 10.^(avg_relative_power_dbB/10);
[rms_delay_spread_modelB, mean_excess_delay_modelB] = delay_spread(delayB, variancesB)

figure(2)
stem(delayB./1e-9, variancesB)
grid on;
xlabel('Time delay [ns]')
ylabel('Average relative power (dB)')
title('COST259-Model B Power-Delay-Profile')

% Model C, corresponding to a typical large open space environment for NLOS
% conditions and 150ns average rms delay spread
delayC = [0 10 20 30 50 80 110 140 180 230 280 330 400 490 600 730 880 1050].*1e-9;
avg_relative_power_dbC = [-3.3 -3.6 -3.9 -4.2 0.0 -0.9 -1.7 -2.6 -1.5 -3.0 -4.4 -5.9 -5.3 -7.9 -9.4 -13.2 -16.3 -21.2];
variancesC = 10.^(avg_relative_power_dbC/10);
[rms_delay_spread_modelC, mean_excess_delay_modelC] = delay_spread(delayC, variancesC)

figure(3)
stem(delayC./1e-9, variancesC)
grid on;
xlabel('Time delay [ns]')
ylabel('Average relative power (dB)')
title('COST259-Model C Power-Delay-Profile')


